@@ -1,10 +1,12 @@
 from pyfiglet import figlet_format
 from typing import List
 from colorama import Fore, Style
+import calendar
+import textwrap as tr
 import sys
 import logging
 from sylo.models import Durations, Config
-import textwrap as tr
+from sylo.utils import get_today, get_weekday
 
 
 logger = logging.getLogger(__name__)
@@ -36,7 +38,8 @@ class Display:
             self.print_header_small()
             self.print_tasks(tasks)
             print(
-                f"{self.col('Press')} {self.col('Ctrl-C', 'yellow')} {self.col('to stop timer early.')}"
+                f"{self.col('Press')} {self.col('Ctrl-C', 'yellow')} "
+                f"{self.col('to stop timer early.')}"
                 "\n"
                 f"\n{self.col('WORK', 'red')} "
                 f"for {self.col(str(timer_val), 'yellow')} minutes"
@@ -95,9 +98,6 @@ class Display:
             f"{self.col('to start the next timer.')}"
         )
 
-    def print_today_yesterday_tasks(self, day: str):
-        print(f"{self.col(day)}")
-
     def print_offer_options(self):
         print(f"{self.col('Press')} {self.col('H', 'yellow')} {self.col('for Help.')}")
 
@@ -133,8 +133,10 @@ class Display:
         return fix_str
 
     def print_splash(self, durations: Durations, mode: str):
+        print(self.col(f"{calendar.day_name[get_weekday()]} {get_today()}"))
+        print(self.col("-----------------------------------------\n"))
         print(
-            f"\nTotal {self.add_plurality(self.pom_name)} today:{self.fix_indent()}      "
+            f"Total {self.add_plurality(self.pom_name)} today:{self.fix_indent()}      "
             f"{self.print_poms(int(durations.poms))}"
             f"\nUpcoming timer:     "
             f"        {self.col(mode.upper(), self._set_mode_color(mode, durations))}"
