@@ -8,15 +8,14 @@ from beepy import beep
 from tqdm import tqdm
 from colorama import Fore
 from typing import List
+from time import sleep
 from sylo.models import (
     Durations,
     Database,
     ConfigFile,
 )
 from sylo.definitions import (
-    TODAY_STR,
-    YESTERDAY_STR,
-    WELCOME_CHOICES,
+    INPUT_OPTIONS,
     COUNTDOWN_INCREMENTS,
     METRICS_BAR,
     METRICS_HEAT,
@@ -34,6 +33,9 @@ from sylo.utils import (
     get_input,
     run_subprocess,
     check_for_dir,
+    get_today,
+    generate_date_range,
+    valid_input,
 )
 from sylo.display import Display
 
@@ -60,7 +62,7 @@ class Timer:
             f'"description",'
             f'"effort",'
             f'"complete"'
-            f"FROM tasks WHERE \"task_date\" = '{TODAY_STR}' "
+            f"FROM tasks WHERE \"task_date\" = '{get_today()}' "
             f";"
         )
 
@@ -197,7 +199,7 @@ class Insights:
 class Task:
     def __init__(self):
         self.description = None
-        self.date = TODAY_STR
+        self.date = get_today()
         self.complete = 0
         self.effort = 1
 
@@ -256,9 +258,9 @@ class Sylo:
         )
 
     def show_task(self, dates, with_id: bool = False):
-        for date, day in zip(dates, ["YESTERDAY", "TODAY"]):
+        for date in dates:
             print("\n")
-            display.print_today_yesterday_tasks(day)
+            print(display.col(date))
             print(display.col("-----------------------------------------\n"))
             self.tasks = database.select(
                 f"SELECT"
@@ -274,70 +276,100 @@ class Sylo:
                 display.print_tasks(self.tasks)
             else:
                 display.print_tasks_with_id(self.tasks)
+            logger.info(f"Tasks: {self.tasks}")
+        return [i[0] for i in self.tasks]
 
-    def edit_task_menu(self, dates: List):
+    def task_menu_new(self, dates: List, task: Task):
+        display.print_new_task()
+        task.description = input(display.col("Description >> ", "yellow"))
+        task.effort = input(
+            display.col(
+                f"Effort (in" f" {display.add_plurality(display.pom_name)}) >> ",
+                "yellow",
+            )
+        )
+        while task.effort.isnumeric() is False:
+            print(display.col("MUST BE NUMERIC", "red"))
+            sleep(2)
+            self.task_menu(dates)
+        task.write_task_to_db()
+        self.task_menu(dates)
+
+    def task_menu_close(self, dates: List):
+        clear_screen()
+        display.print_header_small()
+        task_ids = self.show_task(dates, True)
+        display.print_edit_task()
+        comp_input = input(display.col("Task id >> ", "yellow"))
+        while valid_input(comp_input, task_ids) is False:
+            print(display.col("NOT A VALID ID", "red"))
+            sleep(2)
+            self.task_menu(dates)
+        database.execute(
+            f'UPDATE tasks SET "complete" = '
+            f'CASE WHEN "complete" = False THEN True ELSE False END'
+            f' WHERE "id" = {comp_input};'
+        )
+        self.task_menu(dates)
+
+    def task_menu_move(self, dates: List):
+        clear_screen()
+        display.print_header_small()
+        task_ids = self.show_task(dates, True)
+        display.print_edit_task()
+        comp_input = input(display.col("Task id >> ", "yellow"))
+        while valid_input(comp_input, task_ids) is False:
+            print(display.col("NOT A VALID ID", "red"))
+            sleep(2)
+            self.task_menu(dates)
+        database.execute(
+            f"UPDATE tasks SET \"task_date\" = '{get_today()}'"
+            f' WHERE "id" = {comp_input};'
+        )
+        self.task_menu(dates)
+
+    def task_menu_delete(self, dates: List):
+        clear_screen()
+        display.print_header_small()
+        task_ids = self.show_task(dates, True)
+        display.print_remove_task()
+        comp_input = input(display.col("Task id >> ", "yellow"))
+        while valid_input(comp_input, task_ids) is False:
+            print(display.col("NOT A VALID ID", "red"))
+            sleep(2)
+            self.task_menu(dates)
+        database.execute(f"DELETE FROM tasks" f' WHERE "id" = {comp_input};')
+        self.task_menu(dates)
+
+    def task_menu(self, dates: List):
         clear_screen()
         task = Task()
         display.print_header_small()
         self.show_task(dates)
         display.print_add_task_or_quit()
         usr_input = input(cursor)
+        while valid_input(usr_input, INPUT_OPTIONS["task_menu"]) is False:
+            self.task_menu(dates)
         if usr_input == "":
-            self.input_loop()
+            self.home_loop()
         while usr_input.lower() == "n":
-            display.print_new_task()
-            task.description = input(display.col("Description >> ", "yellow"))
-            task.effort = input(
-                display.col(
-                    f"Effort (in" f" {display.add_plurality(display.pom_name)}) >> ",
-                    "yellow",
-                )
-            )
-            task.write_task_to_db()
-            self.edit_task_menu(dates)
+            self.task_menu_new(dates, task)
         while usr_input.lower() == "c":
-            clear_screen()
-            display.print_header_small()
-            self.show_task(dates, True)
-            display.print_edit_task()
-            comp_input = input(display.col("Task id >> ", "yellow"))
-            database.execute(
-                f'UPDATE tasks SET "complete" = '
-                f'CASE WHEN "complete" = False THEN True ELSE False END'
-                f' WHERE "id" = {comp_input};'
-            )
-            self.edit_task_menu(dates)
+            self.task_menu_close(dates)
         while usr_input.lower() == "m":
-            clear_screen()
-            display.print_header_small()
-            self.show_task(dates, True)
-            display.print_edit_task()
-            comp_input = input(display.col("Task id >> ", "yellow"))
-            database.execute(
-                f"UPDATE tasks SET \"task_date\" = '{TODAY_STR}'"
-                f' WHERE "id" = {comp_input};'
-            )
-            self.edit_task_menu(dates)
+            self.task_menu_move(dates)
         while usr_input.lower() == "d":
-            clear_screen()
-            display.print_header_small()
-            self.show_task(dates, True)
-            display.print_remove_task()
-            comp_input = input(display.col("Task id >> ", "yellow"))
-            database.execute(f"DELETE FROM tasks" f' WHERE "id" = {comp_input};')
-            self.edit_task_menu(dates)
-        while usr_input.lower() not in ("", "n", "c"):
-            self.edit_task_menu(dates)
+            self.task_menu_delete(dates)
 
     def switch_modes(self):
         logger.info("Switch requested")
         self.mode = flip_mode(self.mode)
-        self.input_loop()
+        self.home_loop()
 
     def show_help_menu(self):
         logger.info("Help requested")
         self.show_options ^= True
-        self.input_loop()
+        self.home_loop()
 
     def show_insights_menu(self):
         clear_screen()
@@ -347,7 +379,7 @@ class Sylo:
         metrics.print_heat()
         display.print_insights(durations=self.durations)
         input(cursor)
-        self.input_loop()
+        self.home_loop()
 
     def timer_loop(self, timer: Timer):
         clear_screen()
@@ -363,7 +395,7 @@ class Sylo:
             self.mode = flip_mode(self.mode)
             database.execute(
                 'INSERT INTO sessions ("session_date", "time_worked", "time_rested")'
-                f"VALUES ('{TODAY_STR}',"
+                f"VALUES ('{get_today()}',"
                 f"'{self.durations.total_work_mins}', "
                 f"'{self.durations.total_rest_mins}')"
                 'ON CONFLICT ("session_date") DO UPDATE SET '
@@ -381,7 +413,7 @@ class Sylo:
             self.mode = flip_mode(self.mode)
             database.execute(
                 'INSERT INTO sessions ("session_date", "time_worked", "time_rested")'
-                f"VALUES ('{TODAY_STR}',"
+                f"VALUES ('{get_today()}',"
                 f"'{self.durations.total_work_mins}', "
                 f"'{self.durations.total_rest_mins}')"
                 'ON CONFLICT ("session_date") DO UPDATE SET '
@@ -389,7 +421,7 @@ class Sylo:
             )
             database.execute(
                 'INSERT INTO poms ("poms_date", "poms")'
-                f"VALUES ('{TODAY_STR}',"
+                f"VALUES ('{get_today()}',"
                 f"'{self.durations.poms}')"
                 'ON CONFLICT ("poms_date") DO UPDATE SET '
                 '"poms" = excluded."poms"'
@@ -399,7 +431,7 @@ class Sylo:
         logger.info(f"Work time: {self.durations.total_work_mins}")
         logger.info(f"Work time: {self.durations.total_rest_mins}")
         initial_boot_flag = False
-        self.input_loop()
+        self.home_loop()
 
     @staticmethod
     def quit_app():
@@ -407,16 +439,16 @@ class Sylo:
         clear_screen()
         sys.exit()
 
-    def input_loop(self):
+    def home_loop(self):
         self.on_boot()
         timer = Timer(self.mode, self.durations, self.increments)
         self.splash(timer)
         response = get_input(cursor)
         logger.info(f"User response: {response}")
-        while response.lower() not in WELCOME_CHOICES:
+        while valid_input(response, INPUT_OPTIONS["home"]) is False:
             self.show_options = True
             logger.info(f"Rejected user response of {response}")
-            self.input_loop()
+            self.home_loop()
         while response.lower() == "q":
             self.quit_app()
         while response.lower() == "i":
@@ -426,12 +458,7 @@ class Sylo:
         while response.lower() == "h":
             self.show_help_menu()
         while response.lower() == "t":
-            self.edit_task_menu(
-                [
-                    YESTERDAY_STR,
-                    TODAY_STR,
-                ]
-            )
+            self.task_menu(generate_date_range(get_today(), 7))
         while response == "":
             self.timer_loop(timer)
 
@@ -494,4 +521,4 @@ def run(args, config):
         mode=timer_mode,
         speed_mode=is_speed_mode,
     )
-    sylo.input_loop()
+    sylo.home_loop()
